import gumsense
import subprocess, sys, os, os.path, signal, time, types
import netif

GPRS_TERM = "/dev/ttyS2"
GPRS_BAUD = 38400

PPP_PID_FILE = "/var/run/ppp-gw.pid"

def registered():
    """Returns True if the GPRS has registered with a GPRS service"""
    p = subprocess.Popen( "gwgsm -b %i -p %s check-gprs" % (GPRS_BAUD, GPRS_TERM),
                          shell = True, stdout = sys.stdout, stderr = sys.stderr )

    r = p.wait()

    if r == 0:
        return True
    return False

def wait_for_registration():
    """Blocks until the modem has registered with a GPRS service"""
    print "Waiting for GPRS registration..."
    while not registered():
        time.sleep(1)
        print "Still waiting."
    print "GSM modem registered with GPRS service"

def net_exists(ifname):
    """Returns True if the given interface name exists"""
    return os.path.exists( "/sys/class/net/%s" % ifname )

def conn_info():
    """Returns a tuple containing:
       0) The PID of pppd
       1) The interface name.
       If there's no pppd instance, returns False"""
    if not os.path.exists( PPP_PID_FILE ):
        return False

    try:
        f = open( PPP_PID_FILE )
    
        pid = int (f.readline().strip())
        ifname = f.readline().strip()
        return (pid,ifname)
    except:
        return False
    
def start_connecting(): 
    p = subprocess.Popen( "pppd call glacs-isp",
                          shell = True, stdout = sys.stdout, stderr = sys.stderr )
    r = p.wait()
    if r != 0:
        print "Error!  pppd failed with exit status %i" % r
        return

def disconnect():
    """Disconnects and waits for pppd to terminate"""
    ci = conn_info()

    if type(ci) != types.TupleType:
        # pppd isn't running
        return

    pid,ifname = ci

    os.kill( pid, signal.SIGTERM )

    while os.path.exists( PPP_PID_FILE ):
        time.sleep(1)

def ppp_is_up():
    """Returns True when the connection is up"""
    ci = conn_info()

    if type(ci) != types.TupleType:
        return False

    pid, ifname = ci

    if ifname in netif.all_interfaces():
        return True
    return False

