import subprocess, time

### Power rails
# Level translator rail
TRANS_RAIL = 4
# Probe rail
PROBE_RAIL = 5
# SHT rail
SHT_RAIL = 6
# Tune rail
TUNE_RAIL = 7

### IO lines
# The Turbo light
TURBO_IO = 7
# VGPRS enable
VGPRS_IO = 0
# VGPS enable
VGPS_IO = 1
# VSPARE enable
VSPARE_IO = 2

def ping():
    """Keep the Gumstix alive by pinging the Gumsense"""
    p = subprocess.Popen( args = "gum-ping", shell = True )
    p.wait()

def set_wakeup_time( ts ):
    """Set the Gumstix wakeup time.
    Args:
         ts - The timestamp to wake at."""

    f = open("/dev/null", "w")

    p = subprocess.Popen( args = "gum-waketime %i" % (ts), 
                          shell = True,
                          stdout = f )
    p.wait()
    f.close()

def power_conf( num, on ):
    """Configure a power rail"""
    s = "o"
    if not on:
        s = "f"

    f = open("/dev/null","w")

    p = subprocess.Popen( args = "gum-power -%s %i" % (s, num), 
                          shell = True,
                          stdout = f )
    p.wait()
    f.close()

def power_probe( on ):
    """Turn the probe on/off"""
    power_conf( PROBE_RAIL, on )

def power_translators( on ):
    """Turn the level translators on/off"""
    power_conf( TRANS_RAIL, on )

def power_sht( on ):
    """Turn the SHT rail on/off"""
    power_conf( SHT_RAIL, on )

def power_tune( on ):
    """Turn the tune generator rail on/off"""
    power_conf( TUNE_RAIL, on )

def output_set( num, on ):
    """Turn an output on/off"""
    s = "L"
    if on:
        s = "H"
    
    f = open("/dev/null","w")

    p = subprocess.Popen( args = "gum-io -o %i %s" % (num, s), 
                          shell = True,
                          stdout = f )
    p.wait()
    f.close()
    
def turbo_light( on ):
    """Turn the turbo light on/off"""
    output_set( TURBO_IO, on )

def power_gprs( on ):
    """Turn the GPRS rail on/off"""
    output_set( VGPRS_IO, on )

def power_gps( on ):
    """Turn the GPS rail on/off"""
    output_set( VGPS_IO, on )

def power_spare( on ):
    """Turn the spare rail on/off"""
    output_set( VSPARE_IO, on )

def beep():
    power_spare(True)
    time.sleep(0.2)
    power_spare(False)
