import datetime

class Job:
    """Represents a job"""
    def __init__(self, conf_line):
        """conf_line is the line from the configuration file for this job"""
        # Split on whitespace into 4 fields   
        self.day,self.hour,self.minute,self.cmd = conf_line.split(None,3)
        
        if (not self.hour.isdigit()) or (not self.minute.isdigit()):
            raise "Non-numerical hour and minutes are unsupported"
        self.hour = int(self.hour)
        self.minute = int(self.minute)

        if self.day != "*" and not self.day.isdigit():
            raise "Unsupported day code '%s'" % (self.day)
        if self.day != "*":
            self.day = int(self.day)

    def __repr__(self):
        return str((self.day,self.hour,self.minute,self.cmd))

    def next_time(self, orig):
        """Return the next execution time after time t
        Takes a datetime object, returns a datetime object"""
        next = orig.replace( minute = self.minute, 
                             hour = self.hour, 
                             second = 0,
                             microsecond = 0 )

        # If not due today, increment
        if self.day != "*" and next.weekday() != self.day:
            # Not due today -- add the right number of days on
            ndays = (self.day - next.weekday()) % 7
            next = next + datetime.timedelta( days = ndays )

        # Job may have already passed
        if next < orig:
            inc = 1
            if self.day != "*":
                inc = 7

            next = next + datetime.timedelta(days=inc)

        return next

class JobList:
    """Opens and parses a file describing jobs"""
    def __init__(self, fname):
        self.__parse_file__(fname)

    def __parse_file__(self, fname):
        """Private function that loads information from a file"""
        f = open(fname, "r")
        self.jobs = []
        
        for l in f:
            l = l.strip()
            if len(l)==0 or l[0] == '#':
                continue
            self.jobs.append( Job(l) )
        
        f.close()
